@@ -30,7 +30,7 @@ class MySQLClient:
         :return 编码后的字符串
         '''
         if type(value) == int:
-            return value
+            return str(value)
         return html.escape(value)
 
     def html_unescape(self, value: str):
@@ -76,19 +76,22 @@ class MySQLClient:
             self.close()
         return result
 
-    def fetch(self, fields: list, table: str, query: str, close: bool = True):
+    def fetch(self, fields: list, table: str, query: str = '', close: bool = True):
         '''
         查询数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param fields 要查询的字段名
         :param table 表名
-        :param query 查询条件
+        :param query 查询条件，默认为空
         :param close 是否自动关闭数据库连接，默认True
         :return {list} 如没有查询结果则返回None
         '''
-        sql = 'SELECT %s FROM %s WHERE %s' % (
+        where_str = ''
+        if query != '':
+            where_str = 'WHERE %s' % query
+        sql = 'SELECT %s FROM %s %s' % (
             ','.join(fields),
             table,
-            query
+            where_str
         )
         try:
             # 执行SQL语句
@@ -113,25 +116,56 @@ class MySQLClient:
             res_data.append(col_data)
         return res_data
 
-    def update(self, table: str, set: dict, query: str, close: bool = True):
+    def fetch_count(self, table: str, query: str = '', close: bool = True):
+        '''
+        查询数据结果条数，查询条件数据建议使用html_escape转码保证数据查询安全
+        :param table 表名
+        :param query 查询条件
+        :param close 是否自动关闭数据库连接，默认True
+        :return {list} 如没有查询结果则返回None
+        '''
+        where_str = ''
+        if query != '':
+            where_str = 'WHERE %s' % query
+        sql = 'SELECT count(id) FROM %s %s' % (
+            table,
+            where_str
+        )
+        try:
+            # 执行SQL语句
+            self.cursor.execute(sql)
+            # 获取所有记录列表
+            results = self.cursor.fetchone()
+        except:
+            print("Error: unable to fetch data")
+        # 关闭数据库连接
+        if close:
+            self.close()
+        # 没有查询结果则返回None
+        return results[0]
+
+    def update(self, table: str, set: dict, query: str = '', close: bool = True):
         '''
         更新数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param table 表名
         :param set 需要修改的内容
-        :param query 查询条件
+        :param query 查询条件，默认为空
         :param close 是否自动关闭数据库连接，默认True
         :return {bool} True/False
         '''
         result = False
+        where_str = ''
+        if query != '':
+            where_str = 'WHERE %s' % query
         set_list = []
         for key in set.keys():
             set_list.append(
                 '%s="%s"' % (key, self.html_escape(set[key]))
             )
-        sql = 'UPDATE %s SET %s WHERE %s' % (
+        sql = 'UPDATE %s SET %s %s' % (
             table,
             ','.join(set_list),
-            query
+            where_str
         )
         try:
             # 执行SQL语句
@@ -148,18 +182,21 @@ class MySQLClient:
             self.close()
         return result
 
-    def delete(self, table: str, query: str, close: bool = True):
+    def delete(self, table: str, query: str = '', close: bool = True):
         '''
         删除数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param table 表名
-        :param query 查询条件
+        :param query 查询条件，默认为空
         :param close 是否自动关闭数据库连接，默认True
         :return {bool} True/False
         '''
         result = False
-        sql = 'DELETE FROM %s WHERE %s' % (
+        where_str = ''
+        if query != '':
+            where_str = 'WHERE %s' % query
+        sql = 'DELETE FROM %s %s' % (
             table,
-            query
+            where_str
         )
         try:
             # 执行SQL语句
